@@ -58,7 +58,7 @@ if not sys.warnoptions:
 if sys.platform != "win32":
 	import fcntl
 
-n_version = "8.2.0" # Should also be bumped in pyproject.toml, extra/*.appdata.xml
+n_version = "8.2.2" # Should also be bumped in pyproject.toml, extra/*.appdata.xml
 t_version = "v" + n_version
 t_title = "Tauon"
 t_id = "tauonmb"
@@ -67,6 +67,8 @@ t_agent = "TauonMusicBox/" + n_version
 logging.info(f"{t_title} {t_version}")
 logging.info("Copyright 2015-2025 Taiko2k captain.gxj@gmail.com\n")
 
+logging.info(f"Started with arguments: {sys.argv}")
+
 def open_discord() -> None:
 	webbrowser.open("https://discord.gg/v4EmhES")
 
@@ -201,6 +203,8 @@ if d in ["GNOME:Phosh"]:
 	os.environ["SDL_VIDEODRIVER"] = "wayland"
 	phone = True
 
+os.environ["SDL_VIDEO_WAYLAND_ALLOW_LIBDECOR"] = "0"  # emergency crash workaround
+
 if pyinstaller_mode: # and sys.platform == 'darwin':
 	os.environ["SDL_BINARY_PATH"] = str(install_directory)
 
